@@ -12,7 +12,6 @@ except ImportError:
     # Django < 1.8
     from django.template.loader import BaseLoader
 
-from djblets.deprecation import RemovedInDjblets20Warning
 from djblets.extensions.manager import get_extension_managers
 
 
@@ -46,28 +45,3 @@ class Loader(BaseLoader):
                         pass
 
         raise TemplateDoesNotExist(template_name)
-
-
-_loader = None
-
-
-def load_template_source(template_name, template_dirs=None):
-    """Load templates from enabled extensions.
-
-    .. deprecated:: 0.9
-       This will be removed in a future version. You should instead include
-       ``djblets.extensions.loaders.Loader`` in the list of template loaders.
-    """
-    global _loader
-
-    warnings.warn(
-        "'djblets.extensions.loaders.load_template_source' is deprecated; "
-        "use 'djblets.extensions.loaders.Loader' instead.",
-        RemovedInDjblets20Warning)
-
-    if _loader is None:
-        _loader = Loader()
-
-    return _loader.load_template_source(template_name, template_dirs)
-
-load_template_source.is_usable = True
