@@ -1,13 +1,13 @@
 from __future__ import unicode_literals
 
 from django.http import HttpResponse
-from django.shortcuts import render
 from django.template.context import RequestContext
 from django.utils.six.moves import http_client
 from django.utils.six.moves.urllib.error import URLError
 from django.utils.six.moves.urllib.request import urlopen
 
 from djblets.cache.backend import cache_memoize
+from djblets.util.compat.django.shortcuts import render
 from djblets.util.compat.django.template.loader import render_to_string
 
 
