@@ -29,16 +29,14 @@ from hashlib import md5
 from warnings import warn
 
 from django.conf import settings
-from django.http import QueryDict
 from django.utils import six
-
-from djblets.deprecation import RemovedInDjblets20Warning
+from django.utils.six.moves.urllib.parse import urlencode
 
 
 default_app_config = 'djblets.gravatars.apps.GravatarsAppConfig'
 
 
-def get_gravatar_url_for_email(request=None, email=None, size=None):
+def get_gravatar_url_for_email(email=None, size=None):
     """Return the Gravatar URL for an e-mail address.
 
     The returned URL will always use HTTPS.
@@ -48,9 +46,6 @@ def get_gravatar_url_for_email(request=None, email=None, size=None):
     if using :py:mod:`djblets.avatars`.
 
     Args:
-        request (django.http.HttpRequest):
-            Ignored. This argument will be removed in Djblets 2.0.
-
         email (unicode):
             The e-mail address to get the Gravatar URL for.
 
@@ -61,13 +56,6 @@ def get_gravatar_url_for_email(request=None, email=None, size=None):
         unicode:
         The URL for the Gravatar associated with the given e-mail address.
     """
-    if request is not None:
-        warn("djblets.gravatars.get_gravatar_url_for_email's request "
-             "argument is deprecated and should be None. It will be removed "
-             "in Djblets 2.0. Use get_gravatar_url_for_email(email=email, "
-             "size=size) instead.",
-             RemovedInDjblets20Warning)
-
     if email:
         email = email.strip().lower()
 
@@ -79,27 +67,27 @@ def get_gravatar_url_for_email(request=None, email=None, size=None):
         email_hash = '00000000000000000000000000000000'
 
     url = 'https://secure.gravatar.com/avatar/%s' % email_hash
-    params = QueryDict('', mutable=True)
+    params = []
 
     if not size and hasattr(settings, 'GRAVATAR_SIZE'):
         size = settings.GRAVATAR_SIZE
 
     if size:
-        params['s'] = size
+        params.append(('s', size))
 
     if hasattr(settings, 'GRAVATAR_RATING'):
-        params['r'] = settings.GRAVATAR_RATING
+        params.append(('r', settings.GRAVATAR_RATING))
 
     if hasattr(settings, 'GRAVATAR_DEFAULT'):
-        params['d'] = settings.GRAVATAR_DEFAULT
+        params.append(('d', settings.GRAVATAR_DEFAULT))
 
-    if len(params):
-        url = '%s?%s' % (url, params.urlencode())
+    if params:
+        url = '%s?%s' % (url, urlencode(params))
 
     return url
 
 
-def get_gravatar_url(request=None, user=None, size=None):
+def get_gravatar_url(user=None, size=None):
     """Return the Gravatar URL for a user.
 
     The returned URL will always use HTTPS.
@@ -109,9 +97,6 @@ def get_gravatar_url(request=None, user=None, size=None):
     if using :py:mod:`djblets.avatars`.
 
     Args:
-        request (django.http.HttpRequest):
-            Ignored. This argument will be removed in Djblets 2.0.
-
         user (django.contrib.auth.models.User):
             The user whose Gravatar URL is to be retrieved.
 
@@ -126,12 +111,6 @@ def get_gravatar_url(request=None, user=None, size=None):
         ValueError:
             Raised if ``user`` is ``None``.
     """
-    if request is not None:
-        warn("djblets.gravatars.get_gravatar_url's request request argument "
-             "is deprecated and should be None. It will be removed in Djblets "
-             "2.0. Use get_gravatar_url(user=user, size=size) instead.",
-             RemovedInDjblets20Warning)
-
     if user is None:
         raise ValueError('"user" cannot be None.')
 
