@@ -36,12 +36,13 @@ import time
 from django.conf import settings
 from django.contrib.admin.views.decorators import staff_member_required
 from django.http import Http404
-from django.shortcuts import render
 from django.template.context import RequestContext
 from django.utils import six
 from django.utils.six.moves.urllib.parse import urlencode
 from django.utils.translation import ugettext_lazy as _
 
+from djblets.util.compat.django.shortcuts import render
+
 
 LEVELS = (
     (logging.DEBUG, 'debug', _('Debug')),
